@@ -1,7 +1,7 @@
 use atty::Stream;
 use base64::decode as base64_decode;
 use chrono::{TimeZone, Utc};
-use clap::{AppSettings, ArgEnum, Parser, Subcommand};
+use clap::{ArgEnum, Parser, Subcommand};
 use jsonwebtoken::errors::{ErrorKind, Result as JWTResult};
 use jsonwebtoken::{
     dangerous_insecure_decode, decode, encode, Algorithm, DecodingKey, EncodingKey, Header,
@@ -121,8 +121,7 @@ impl TokenOutput {
 #[derive(Parser, Debug)]
 #[clap(name = "jwt")]
 #[clap(about, version, author)]
-#[clap(global_setting(AppSettings::PropagateVersion))]
-#[clap(global_setting(AppSettings::UseLongFormatForHelpSubcommand))]
+#[clap(propagate_version = true)]
 struct App {
     #[clap(subcommand)]
     command: Commands,
@@ -293,13 +292,13 @@ fn slurp_file(file_name: &str) -> Vec<u8> {
 fn parse_duration_string(val: &str) -> Result<i64, String> {
     let mut base_val = val.replace(" ago", "");
 
-    if val.starts_with("-") {
-        base_val = base_val.replacen("-", "", 1);
+    if val.starts_with('-') {
+        base_val = base_val.replacen('-', "", 1);
     }
 
     match parse_duration::parse(&base_val) {
         Ok(parsed_duration) => {
-            let is_past = val.starts_with("-") || val.contains("ago");
+            let is_past = val.starts_with('-') || val.contains("ago");
             let seconds = parsed_duration.as_secs() as i64;
 
             if is_past {
